@@ -41,7 +41,6 @@ logging = log.getLogger(__name__)
 
 from MoinMoin import config, caching, user, util, wikiutil
 from MoinMoin.logfile import eventlog
-from MoinMoin.util import filesys
 
 def is_cache_exception(e):
     args = e.args
@@ -492,7 +491,7 @@ class Page(object):
                 os.makedirs(dirname)
             except OSError, err:
                 if not os.path.exists(dirname):
-                    raise err
+                    raise
         return underlay, fullpath
 
     def getPagePath(self, *args, **kw):
@@ -1057,8 +1056,8 @@ class Page(object):
                 if 'highlight' in request.form:
                     del request.form['highlight']
                 request.theme.add_msg(_('Invalid highlighting regular expression "%(regex)s": %(error)s') % {
-                                          'regex': self.hilite_re,
-                                          'error': str(err),
+                                          'regex': wikiutil.escape(self.hilite_re),
+                                          'error': wikiutil.escape(str(err)),
                                       }, "warning")
                 self.hilite_re = None
 
@@ -1115,7 +1114,7 @@ class Page(object):
                     request.theme.add_msg("<strong>%s</strong><br>" % (
                         _('Revision %(rev)d as of %(date)s') % {
                             'rev': self.rev,
-                            'date': self.mtime_printable(request)
+                            'date': wikiutil.escape(self.mtime_printable(request))
                         }), "info")
 
                 # This redirect message is very annoying.
@@ -1263,7 +1262,10 @@ class Page(object):
             self.getFormatterName() in self.cfg.caching_formats):
             # Everything is fine, now check the parser:
             if parser is None:
-                parser = wikiutil.searchAndImportPlugin(self.request.cfg, "parser", self.pi['format'])
+                try:
+                    parser = wikiutil.searchAndImportPlugin(self.request.cfg, "parser", self.pi['format'])
+                except wikiutil.PluginMissingError:
+                    return False
             return getattr(parser, 'caching', False)
         return False
 
@@ -1278,7 +1280,10 @@ class Page(object):
         """
         request.clock.start('send_page_content')
         # Load the parser
-        Parser = wikiutil.searchAndImportPlugin(request.cfg, "parser", format)
+        try:
+            Parser = wikiutil.searchAndImportPlugin(request.cfg, "parser", format)
+        except wikiutil.PluginMissingError:
+            Parser = wikiutil.searchAndImportPlugin(request.cfg, "parser", "plain")
         parser = Parser(body, request, format_args=format_args, **kw)
 
         if not (do_cache and self.canUseCache(Parser)):
@@ -1407,7 +1412,7 @@ class Page(object):
         if self.page_name:
             rev_dir = self.getPagePath('revisions', check_create=0)
             if os.path.isdir(rev_dir):
-                for rev in filesys.dclistdir(rev_dir):
+                for rev in os.listdir(rev_dir):
                     try:
                         revint = int(rev)
                         revisions.append(revint)
@@ -1834,7 +1839,7 @@ class RootPage(Page):
         @return: dict of page names using file system encoding
         """
         pages = {}
-        for name in filesys.dclistdir(path):
+        for name in os.listdir(path):
             # Filter non-pages in quoted wiki names
             # List all pages in pages directory - assume flat namespace.
             # We exclude everything starting with '.' to get rid of . and ..
