@@ -171,14 +171,15 @@ Please review the page and save then. Do not save this page as it is!""")
         elif 'template' in form:
             # If the page does not exist, we try to get the content from the template parameter.
             template_page = wikiutil.unquoteWikiname(form['template'][0])
+            template_page_escaped = wikiutil.escape(template_page)
             if request.user.may.read(template_page):
                 raw_body = Page(request, template_page).get_raw_body()
                 if raw_body:
-                    request.write(_("[Content of new page loaded from %s]") % (template_page, ), '<br>')
+                    request.write(_("[Content of new page loaded from %s]") % (template_page_escaped, ), '<br>')
                 else:
-                    request.write(_("[Template %s not found]") % (template_page, ), '<br>')
+                    request.write(_("[Template %s not found]") % (template_page_escaped, ), '<br>')
             else:
-                request.write(_("[You may not read %s]") % (template_page, ), '<br>')
+                request.write(_("[You may not read %s]") % (template_page_escaped, ), '<br>')
 
         # Make backup on previews - but not for new empty pages
         if not use_draft and preview and raw_body:
@@ -314,7 +315,7 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
         url_prefix_static = request.cfg.url_prefix_static
         url_prefix_local = request.cfg.url_prefix_local
         wikipage = wikiutil.quoteWikinameURL(self.page_name)
-        fckbasepath = url_prefix_local + '/applets/FCKeditor'
+        fckbasepath = request.cfg.url_prefix_fckeditor
         wikiurl = request.getScriptname()
         if not wikiurl or wikiurl[-1] != '/':
             wikiurl += '/'
