@@ -11,7 +11,6 @@ import os
 import py
 
 from MoinMoin import user, caching
-from MoinMoin.util import filesys
 
 
 class TestEncodePassword(object):
@@ -46,8 +45,6 @@ class TestLoginWithPassword(object):
         self.request.saved_cookie = ''
         self.request.user = user.User(self.request)
 
-        # Prevent user list caching - we create and delete users too fast for that.
-        filesys.dcdisable()
         self.user = None
 
     def teardown_method(self, method):
@@ -75,9 +72,6 @@ class TestLoginWithPassword(object):
         except:
             pass
 
-        # Prevent user list caching - we create and delete users too fast for that.
-        filesys.dcdisable()
-
     def testAsciiPassword(self):
         """ user: login with ascii password """
         # Create test user
