@@ -83,7 +83,12 @@ def attachUrl(request, pagename, filename=None, **kw):
             and
             kw.get('rename') is None):
         # create a ticket for the not so harmless operations
-        kw['ticket'] = wikiutil.createTicket(request)
+        # we need action= here because the current action (e.g. "show" page
+        # with a macro AttachList) may not be the linked-to action, e.g.
+        # "AttachFile". Also, AttachList can list attachments of another page,
+        # thus we need to give pagename= also.
+        kw['ticket'] = wikiutil.createTicket(request,
+                                             pagename=pagename, action=action_name)
     if kw:
         qs = '?%s' % wikiutil.makeQueryString(kw, want_unicode=False)
     else:
@@ -338,7 +343,7 @@ def _build_filelist(request, pagename, showheader, readonly, mime_type='*'):
 
             try:
                 is_zipfile = zipfile.is_zipfile(fullpath)
-                if is_zipfile:
+                if is_zipfile and not readonly:
                     is_package = packages.ZipPackage(request, fullpath).isPackage()
                     if is_package and request.user.isSuperUser():
                         links.append(fmt.url(1, getAttachUrl(pagename, file, request, do='install')) +
