@@ -6,29 +6,30 @@
                 2006 MoinMoin:ThomasWaldmann
     @license: GNU GPL, see COPYING for details.
 """
+from MoinMoin import wikiutil
 from MoinMoin.util import pysupport
 
 def execute(pagename, request):
     """ Show page charts """
     _ = request.getText
     if not request.user.may.read(pagename):
-        msg = _("You are not allowed to view this page.", formatted=False)
-        return request.page.send_page(msg=msg)
+        request.theme.add_msg(_("You are not allowed to view this page."), "error")
+        return request.page.send_page()
 
     if not request.cfg.chart_options:
-        msg = _("Charts are not available!", formatted=False)
-        return request.page.send_page(msg=msg)
+        request.theme.add_msg(_("Charts are not available!"), "error")
+        return request.page.send_page()
 
     chart_type = request.form.get('type', [''])[0].strip()
     if not chart_type:
-        msg = _('You need to provide a chart type!', formatted=False)
-        return request.page.send_page(msg=msg)
+        request.theme.add_msg(_('You need to provide a chart type!'), "error")
+        return request.page.send_page()
 
     try:
         func = pysupport.importName("MoinMoin.stats.%s" % chart_type, 'draw')
     except (ImportError, AttributeError):
-        msg = _('Bad chart type "%s"!', formatted=False) % chart_type
-        return request.page.send_page(msg=msg)
+        request.theme.add_msg(_('Bad chart type "%s"!') % wikiutil.escape(chart_type), "error")
+        return request.page.send_page()
 
     func(pagename, request)
 
