@@ -10,6 +10,7 @@
 """
 
 from MoinMoin import config, wikiutil, action
+from MoinMoin.action import AttachFile
 from MoinMoin.Page import Page
 from MoinMoin.logfile import editlog
 from MoinMoin.widget import html
@@ -101,8 +102,19 @@ def execute(pagename, request):
             kw.update(dict(rel='nofollow'))
             return page.link_to(request, text, querystr=query, **kw)
 
+        def render_file_action(text, pagename, filename, request, do, drawing=''):
+            url = AttachFile.getAttachUrl(pagename, filename, request, do=do, drawing=drawing)
+            if url:
+                f = request.formatter
+                link = f.url(1, url) + f.text(text) + f.url(0)
+                return link
+
         # read in the complete log of this page
         log = editlog.EditLog(request, rootpagename=pagename)
+
+        may_write = request.user.may.write(pagename)
+        may_delete = request.user.may.delete(pagename)
+
         count = 0
         pgactioncount = 0
         for line in log.reverse():
@@ -135,19 +147,20 @@ def execute(pagename, request):
 
                 filename = wikiutil.url_unquote(line.extra)
                 comment = "%s: %s %s" % (line.action, filename, line.comment)
-                size = 0
-                if line.action != 'ATTDEL':
-                    from MoinMoin.action import AttachFile
-                    if AttachFile.exists(request, pagename, filename):
-                        size = AttachFile.size(request, pagename, filename)
+                if AttachFile.exists(request, pagename, filename):
+                    size = AttachFile.size(request, pagename, filename)
                     if line.action == 'ATTNEW':
-                        actions.append(render_action(_('view'), {'action': 'AttachFile', 'do': 'view', 'target': '%s' % filename}))
-                    elif line.action == 'ATTDRW':
-                        actions.append(render_action(_('edit'), {'action': 'AttachFile', 'drawing': '%s' % filename.replace(".draw", "")}))
-
-                    actions.append(render_action(_('get'), {'action': 'AttachFile', 'do': 'get', 'target': '%s' % filename}))
-                    if request.user.may.delete(pagename):
-                        actions.append(render_action(_('del'), {'action': 'AttachFile', 'do': 'del', 'target': '%s' % filename}))
+                        actions.append(render_file_action(_('view'), pagename, filename, request, do='view'))
+                    elif may_write and line.action == 'ATTDRW':
+                        actions.append(render_file_action(_('view'), pagename, filename.replace(".draw", ".png"),
+                                                          request, do='view'))
+                        actions.append(render_file_action(_('edit'), pagename, filename, request, do='edit',
+                                                          drawing=filename.replace(".draw", "")))
+                    actions.append(render_file_action(_('get'), pagename, filename, request, do='get'))
+                    if may_delete:
+                        actions.append(render_file_action(_('del'), pagename, filename, request, do='del'))
+                else:
+                    size = 0
 
             history.addRow((
                 rev,
