@@ -8,7 +8,7 @@
     @license: GNU GPL, see COPYING for details.
 """
 
-from MoinMoin import user
+from MoinMoin import user, wikiutil
 from MoinMoin.widget import html
 from MoinMoin.userprefs import UserPrefBase
 
@@ -43,6 +43,9 @@ class Settings(UserPrefBase):
         if request.request_method != 'POST':
             return
 
+        if not wikiutil.checkTicket(request, form.get('ticket', [''])[0]):
+            return
+
         password = form.get('password1', [''])[0]
         password2 = form.get('password2', [''])[0]
 
@@ -78,6 +81,9 @@ class Settings(UserPrefBase):
         self.make_row(_('Password repeat'),
                       [html.INPUT(type="password", size=36, name="password2")])
 
+        ticket = wikiutil.createTicket(self.request)
+        form.append(html.INPUT(type="hidden", name="ticket", value="%s" % ticket))
+
         # Add buttons
         self.make_row('', [
                 html.INPUT(type="submit", name='save', value=_("Change password")),
